Package: radiant.basics
Type: Package
Title: Basics Menu for Radiant: Business Analytics using R and Shiny
Version: 1.6.6
Date: 2024-5-14
Authors@R: person("Vincent", "Nijs", , "radiant@rady.ucsd.edu", c("aut", "cre"))
Description: The Radiant Basics menu includes interfaces for probability 
    calculation, central limit theorem simulation, comparing means and proportions, 
    goodness-of-fit testing, cross-tabs, and correlation. The application extends 
    the functionality in 'radiant.data'.
Depends: R (>= 4.3.0), radiant.data (>= 1.6.6)
Imports: ggplot2 (>= 2.2.1), scales (>= 0.4.0), dplyr (>= 1.0.7), tidyr
        (>= 0.8.2), magrittr (>= 1.5), shiny (>= 1.8.1), psych (>=
        1.8.3.3), import (>= 1.1.0), lubridate (>= 1.7.4), polycor (>=
        0.7.10), patchwork (>= 1.0.0), rlang (>= 1.0.6)
Suggests: testthat (>= 2.0.0), pkgdown (>= 1.1.0), markdown (>= 1.3)
URL: https://github.com/radiant-rstats/radiant.basics/,
        https://radiant-rstats.github.io/radiant.basics/,
        https://radiant-rstats.github.io/docs/
BugReports: https://github.com/radiant-rstats/radiant.basics/issues/
License: AGPL-3 | file LICENSE
LazyData: true
Encoding: UTF-8
Language: en-US
RoxygenNote: 7.3.1
NeedsCompilation: no
Packaged: 2024-05-15 02:24:57 UTC; vnijs
Author: Vincent Nijs [aut, cre]
Maintainer: Vincent Nijs <radiant@rady.ucsd.edu>
Repository: CRAN
Date/Publication: 2024-05-15 04:30:07 UTC
Built: R 4.6.0; ; 2026-05-01 02:20:16 UTC; unix
