# Generated by roxygen2: do not edit by hand

S3method(plot,clt)
S3method(plot,compare_means)
S3method(plot,compare_props)
S3method(plot,correlation)
S3method(plot,cross_tabs)
S3method(plot,goodness)
S3method(plot,prob_binom)
S3method(plot,prob_chisq)
S3method(plot,prob_disc)
S3method(plot,prob_expo)
S3method(plot,prob_fdist)
S3method(plot,prob_lnorm)
S3method(plot,prob_norm)
S3method(plot,prob_pois)
S3method(plot,prob_tdist)
S3method(plot,prob_unif)
S3method(plot,single_mean)
S3method(plot,single_prop)
S3method(print,rcorr)
S3method(summary,compare_means)
S3method(summary,compare_props)
S3method(summary,correlation)
S3method(summary,cross_tabs)
S3method(summary,goodness)
S3method(summary,prob_binom)
S3method(summary,prob_chisq)
S3method(summary,prob_disc)
S3method(summary,prob_expo)
S3method(summary,prob_fdist)
S3method(summary,prob_lnorm)
S3method(summary,prob_norm)
S3method(summary,prob_pois)
S3method(summary,prob_tdist)
S3method(summary,prob_unif)
S3method(summary,single_mean)
S3method(summary,single_prop)
export(clt)
export(compare_means)
export(compare_props)
export(cor2df)
export(correlation)
export(cross_tabs)
export(goodness)
export(prob_binom)
export(prob_chisq)
export(prob_disc)
export(prob_expo)
export(prob_fdist)
export(prob_lnorm)
export(prob_norm)
export(prob_pois)
export(prob_tdist)
export(prob_unif)
export(radiant.basics)
export(radiant.basics_viewer)
export(radiant.basics_window)
export(single_mean)
export(single_prop)
import(ggplot2)
import(radiant.data)
import(shiny)
importFrom(dplyr,arrange)
importFrom(dplyr,bind_cols)
importFrom(dplyr,count)
importFrom(dplyr,filter)
importFrom(dplyr,funs)
importFrom(dplyr,group_by_at)
importFrom(dplyr,left_join)
importFrom(dplyr,mutate)
importFrom(dplyr,mutate_all)
importFrom(dplyr,mutate_if)
importFrom(dplyr,rename)
importFrom(dplyr,select)
importFrom(dplyr,summarise)
importFrom(dplyr,summarise_all)
importFrom(dplyr,summarise_at)
importFrom(graphics,pairs)
importFrom(graphics,par)
importFrom(graphics,plot)
importFrom(graphics,points)
importFrom(graphics,strwidth)
importFrom(graphics,text)
importFrom(import,from)
importFrom(lubridate,is.Date)
importFrom(magrittr,"%<>%")
importFrom(magrittr,"%>%")
importFrom(magrittr,divide_by)
importFrom(magrittr,set_colnames)
importFrom(magrittr,set_names)
importFrom(magrittr,set_rownames)
importFrom(patchwork,plot_annotation)
importFrom(patchwork,wrap_plots)
importFrom(polycor,hetcor)
importFrom(psych,corr.test)
importFrom(radiant.data,launch)
importFrom(rlang,.data)
importFrom(scales,percent)
importFrom(stats,binom.test)
importFrom(stats,chisq.test)
importFrom(stats,cor.test)
importFrom(stats,cov)
importFrom(stats,dbinom)
importFrom(stats,dchisq)
importFrom(stats,dexp)
importFrom(stats,df)
importFrom(stats,dlnorm)
importFrom(stats,dnorm)
importFrom(stats,dpois)
importFrom(stats,dt)
importFrom(stats,dunif)
importFrom(stats,na.omit)
importFrom(stats,p.adjust)
importFrom(stats,pbinom)
importFrom(stats,pchisq)
importFrom(stats,pexp)
importFrom(stats,pf)
importFrom(stats,plnorm)
importFrom(stats,pnorm)
importFrom(stats,ppois)
importFrom(stats,prop.test)
importFrom(stats,pt)
importFrom(stats,punif)
importFrom(stats,qbinom)
importFrom(stats,qchisq)
importFrom(stats,qexp)
importFrom(stats,qf)
importFrom(stats,qlnorm)
importFrom(stats,qnorm)
importFrom(stats,qpois)
importFrom(stats,qt)
importFrom(stats,qunif)
importFrom(stats,rbinom)
importFrom(stats,relevel)
importFrom(stats,rexp)
importFrom(stats,rnorm)
importFrom(stats,runif)
importFrom(stats,sd)
importFrom(stats,setNames)
importFrom(stats,symnum)
importFrom(stats,t.test)
importFrom(stats,wilcox.test)
importFrom(tidyr,gather)
importFrom(tidyr,spread)
importFrom(utils,combn)
